      subroutine derivs(y,dydx,deltaX,iprof)
      implicit double precision (a-h,o-z)
c
c y is an array of cos(theta), sin(theta), z, and travel time.
c Given y, this routine returns the values of 
c   (1) dydx(1)=dcos(theta)/dr,
c   (2) dydx(2)=dsin(theta)/dr, 
c   (3) dydx(3)=dz/dr, and 
c   (4) dydx(4)=dt/dr at r,z,theta.  
c y(1)=cos(theta), y(2)=sin(theta), y(3)=z, y(4)=travel time
c dydx(1)...etc.  are the right hand side of the differential equations
c
c Employs etab to get c, dcdz at arbitrary z
c
c This routine is called a many times when integrating a ray.  A little
c bit of speed improvement here would go a long way.  But there is not much
c room for improvement, it seems to me.  The subroutine drk4.f used to call
c this routine several times, but I inlined the calculations there because it
c seemed to speed things up some.
c
c  Brian Dushaw 
c  Applied Physics Laboratory 
c  University of Washington
c  Seattle, WA 98105
c  (206) 543-1300
c  dushaw@apl.washington.edu
c
c  EIGENRAY Version 3.4
c  September-December 1998
c  Last updated November 2012
c
      double precision y(4),dydx(4),deltaX
      integer iprof

      include 'nssp.h'
      include 'table.h'
      include 'constants.h'

      z=y(3)
      ii=int(xinv_depth_inc*z)
      if(z.lt.zero)ii=-1
      dz=z-tab(ii)
      dz2=dz*half
      dz3=dz*third

       x1=etab(1,ii,iprof)
       x2=etab(2,ii,iprof)
       x3=etab(3,ii,iprof)
       x4=etab(4,ii,iprof)
c get sound speed
       c = ((x4*dz3 + x3)*dz2+x2)*dz+x1

c get sound speed gradient
       dcdz = (x4*dz2 + x3)*dz+x2

c get horizontal gradients
       x1=etab(1,ii,iprof+1)
       x2=etab(2,ii,iprof+1)
       x3=etab(3,ii,iprof+1)
       x4=etab(4,ii,iprof+1)
       cp = ((x4*dz3 + x3)*dz2+x2)*dz+x1
       dcdzp = (x4*dz2 + x3)*dz+x2
       C1=(cp-c)*xinvr(iprof)
       C2=(dcdzp-dcdz)*xinvr(iprof)

c final sound speed, sound speed gradient
       c = c + deltaX*C1
       dcdz = -dcdz - deltaX*C2

       y1_inv=one/y(1)
       c_inv=one/c
c curiously, defining this here saves computation time, whereas this
c trick in drk4.f is counterproductive.  Go figure.  (Likely to be
c  machine/compiler dependent.)
       dydx(3)= y(2)*y1_inv
       q1= (dcdz   - C1*dydx(3))*c_inv

       dydx(1)= -y(2)*q1
       dydx(2)=  y(1)*q1
c       dydx(3)= y(2)*y1_inv
       dydx(4)= c_inv*y1_inv

      return
      end
